==> integration-tests-data-index-service-springboot-1.5.0.Final-sources.jar: org/acme/travels/ApprovalsModelInput.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.acme.travels;

import java.util.Map;
import java.util.HashMap;

@org.kie.kogito.codegen.Generated(value = "kogito-codegen", reference = "approvals", name = "Approvals", hidden = true)
public class ApprovalsModelInput implements org.kie.kogito.Model {

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("approver", this.approver);
        params.put("firstLineApproval", this.firstLineApproval);
        params.put("secondLineApproval", this.secondLineApproval);
        params.put("traveller", this.traveller);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    @Override
    public void update(Map<String, Object> params) {
        fromMap(params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.approver = (java.lang.String) params.get("approver");
        this.firstLineApproval = (java.lang.Boolean) params.get("firstLineApproval");
        this.secondLineApproval = (java.lang.Boolean) params.get("secondLineApproval");
        this.traveller = (org.acme.travels.Traveller) params.get("traveller");
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "approver")
    private java.lang.String approver;

    public java.lang.String getApprover() {
        return approver;
    }

    public void setApprover(java.lang.String approver) {
        this.approver = approver;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "firstLineApproval")
    private java.lang.Boolean firstLineApproval;

    public java.lang.Boolean getFirstLineApproval() {
        return firstLineApproval;
    }

    public void setFirstLineApproval(java.lang.Boolean firstLineApproval) {
        this.firstLineApproval = firstLineApproval;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "secondLineApproval")
    private java.lang.Boolean secondLineApproval;

    public java.lang.Boolean getSecondLineApproval() {
        return secondLineApproval;
    }

    public void setSecondLineApproval(java.lang.Boolean secondLineApproval) {
        this.secondLineApproval = secondLineApproval;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "traveller")
    private org.acme.travels.Traveller traveller;

    public org.acme.travels.Traveller getTraveller() {
        return traveller;
    }

    public void setTraveller(org.acme.travels.Traveller traveller) {
        this.traveller = traveller;
    }

    public ApprovalsModel toModel() {
        ApprovalsModel result = new ApprovalsModel();
        result.setApprover(getApprover());
        result.setFirstLineApproval(getFirstLineApproval());
        result.setSecondLineApproval(getSecondLineApproval());
        result.setTraveller(getTraveller());
        return result;
    }
}

==> integration-tests-data-index-service-springboot-1.7.0.Final-sources.jar: org/acme/travels/ApprovalsModelInput.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.acme.travels;

import java.util.Map;
import java.util.HashMap;

@org.kie.kogito.codegen.Generated(value = "kogito-codegen", reference = "approvals", name = "Approvals", hidden = true)
public class ApprovalsModelInput implements org.kie.kogito.Model {

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap<>();
        params.put("approver", this.approver);
        params.put("firstLineApproval", this.firstLineApproval);
        params.put("secondLineApproval", this.secondLineApproval);
        params.put("traveller", this.traveller);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    @Override
    public void update(Map<String, Object> params) {
        fromMap(params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.approver = (java.lang.String) params.get("approver");
        this.firstLineApproval = (java.lang.Boolean) params.get("firstLineApproval");
        this.secondLineApproval = (java.lang.Boolean) params.get("secondLineApproval");
        this.traveller = (org.acme.travels.Traveller) params.get("traveller");
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "approver")
    private java.lang.String approver;

    public java.lang.String getApprover() {
        return approver;
    }

    public void setApprover(java.lang.String approver) {
        this.approver = approver;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "firstLineApproval")
    private java.lang.Boolean firstLineApproval;

    public java.lang.Boolean getFirstLineApproval() {
        return firstLineApproval;
    }

    public void setFirstLineApproval(java.lang.Boolean firstLineApproval) {
        this.firstLineApproval = firstLineApproval;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "secondLineApproval")
    private java.lang.Boolean secondLineApproval;

    public java.lang.Boolean getSecondLineApproval() {
        return secondLineApproval;
    }

    public void setSecondLineApproval(java.lang.Boolean secondLineApproval) {
        this.secondLineApproval = secondLineApproval;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "traveller")
    private org.acme.travels.Traveller traveller;

    public org.acme.travels.Traveller getTraveller() {
        return traveller;
    }

    public void setTraveller(org.acme.travels.Traveller traveller) {
        this.traveller = traveller;
    }

    public ApprovalsModel toModel() {
        ApprovalsModel result = new ApprovalsModel();
        result.setApprover(getApprover());
        result.setFirstLineApproval(getFirstLineApproval());
        result.setSecondLineApproval(getSecondLineApproval());
        result.setTraveller(getTraveller());
        return result;
    }
}
